@@ -101,5 +101,5 @@ class WSDLService(object):
             }
         }
         for port in self.ports():
-            config[access_point][port] = "{}.xml".format(port)
+            config[self.location][port] = "{}.xml".format(port)
         return config
